@@ -1,4 +1,3 @@
-;;;;; ess-cust.el --- Customization for ESS.
 
 ;; Copyright (C) 1997--2001 A.J. Rossini, Martin Maechler,
 ;; Kurt Hornik, Richard M. Heiberger, and Rodney Sparapani.
@@ -6,9 +5,9 @@
 ;; Author: A.J. Rossini <rossini@u.washington.edu>
 ;; Maintainer: A.J. Rossini <rossini@u.washington.edu>
 ;; Created: 05 June 2000
-;; Modified: $Date: 2002/01/20 06:14:36 $
-;; Version: $Revision: 1.28 $
-;; RCS: $Id: ess-cust.el,v 1.28 2002/01/20 06:14:36 rmh Exp $
+;; Modified: $Date: 2002/08/08 09:02:53 $
+;; Version: $Revision: 1.36 $
+;; RCS: $Id: ess-cust.el,v 1.36 2002/08/08 09:02:53 maechler Exp $
 
 ;; Keywords: editing and process modes.
 
@@ -97,7 +96,7 @@
   :group 'ess-S
   :prefix "ess-")
 
-(defgroup ess-SAS nil
+(defgroup ess-sas nil
   "ESS: SAS."
   :group 'ess
   :prefix "ess-")
@@ -124,7 +123,7 @@
 
 ;; Variables (not user-changeable)
 
-(defcustom ess-version "5.1.20"
+(defcustom ess-version "5.1.24"
   "Version of ESS currently loaded."
   :group 'ess
   :type 'string)
@@ -201,13 +200,23 @@ Used to adjust for changes in versions of the program"
 		 (const :tag "Rwin"   :value "Rwin")))
 
 (make-variable-buffer-local 'ess-dialect)
-(setq-default ess-dialect "Initial-dialect")
+;;(setq-default ess-dialect "Initial-dialect")
+(setq-default ess-dialect nil)		
+;;; SJE -- why use "Initial-dialect"?  If we use nil, it matches "None"
+;;; in the custom choice.
 
 (defcustom ess-directory-function nil
   "*Function to return the directory that ESS is run from.
-If nil or or if returns nil then you get `ess-directory'."
+If nil or if the function returns nil then you get `ess-directory'."
   :group 'ess
-  :type 'directory)
+  :type '(choice (const nil) function))
+
+(defcustom ess-setup-directory-function nil
+  "*Function to setup the directory that ESS is run from.
+This function can be called to set environment variables or to create
+a workspace."
+  :group 'ess
+  :type '(choice (const nil) function))
 
 (defcustom ess-directory nil
   "*The directory ESS is run from.  It must end in a slash.
@@ -216,13 +225,19 @@ A nil value means use the current buffer's default directory.
 Buffer-local: in process buffers, this contains the directory ESS was
 run from."
   :group 'ess
-  :type 'directory)
+  :type '(choice (const nil) directory))
+
+(defcustom ess-history-directory nil
+  "*Directory to pick up `ess-history-file' from.
+If this is nil, the history file is relative to `ess-directory'."
+  :group 'ess
+  :type '(choice (const nil) directory))
 
 (defcustom ess-history-file nil
   "*File to pick up history from.
-If this is a relative file name, it is relative to ess-directory."
+If this is a relative file name, it is relative to `ess-history-directory'."
   :group 'ess
-  :type 'file)
+  :type '(choice (const nil) file))
 
 (defcustom ess-plain-first-buffername t
   "*No fancy process buffname for the first process of each type (novice mode)."
@@ -245,17 +260,23 @@ incorrectly, the right things will probably still happen, however."
   :group 'ess-edit
   :type 'boolean)
 
+;;; SJE -- this is set in ess-site.el to be "always", so I changed 
+;;; value t to be "always", so that ess-site.el does not need editing.
+;;; However, this is a bit messy, and would be nicer if ess-site.el
+;;; value was t rather than "always".
 (defcustom ess-keep-dump-files 'ask
   "*Variable controlling whether to delete dump files after a successful load.
 If nil: always delete.  If `ask', confirm to delete.  If `check', confirm
 to delete, except for files created with ess-dump-object-into-edit-buffer.
 Anything else, never delete.  This variable only affects the behaviour
-of ess-load-file.  Dump files are never deleted if an error occurs
+of `ess-load-file'.  Dump files are never deleted if an error occurs
 during the load. "
   :group 'ess-edit
   :type '(choice (const :tag "Check" :value  'check)
 		 (const :tag "Ask"   :value  'ask)
-		 (const :tag "Keep"   :value 't)))
+		 (const :tag "Always keep"   :value "always")
+		 (const :tag "Always delete"   :value nil)
+		 ))
 
 
 (defcustom ess-delete-dump-files nil
@@ -431,15 +452,18 @@ If not number, the statements are indented at open-parenthesis following
 This can be a string (an absolute directory name ending in a slash) or
 a lambda expression of no arguments which will return a suitable string
 value.  The lambda expression is evaluated with the process buffer as the
-current buffer."
+current buffer.
+
+Possible value:
+
+ '(lambda () (file-name-as-directory
+	      (expand-file-name (concat (car ess-search-list) \"/.Src\"))))
+
+This always dumps to a sub-directory (\".Src\") of the current ess
+working directory (i.e. first elt of search list)."
   :group 'ess-edit
   :type 'directory)
 
-;;; Possible value:
-;;; '(lambda () (file-name-as-directory
-;;;	      (expand-file-name (concat (car ess-search-list) "/.Src"))))
-;;; This always dumps to a sub-directory (".Src") of the current ess
-;;; working directory (i.e. first elt of search list)
 
 (defcustom ess-dump-filename-template (concat (user-login-name) ".%s.S")
   "*Template for filenames of dumped objects.
@@ -510,11 +534,31 @@ Good for evaluating ESS code."
 (defcustom ess-local-process-name nil
   "The name of the ess process associated with the current buffer."
   :group 'ess
-  :type 'string)
+  :type '(choice (const nil) string))
 
 (make-variable-buffer-local 'ess-local-process-name)
 
 
+(defcustom ess-kermit-command "gkermit -T"
+    "*Kermit command invoked by `ess-kermit-get' and `ess-kermit-send'."
+    :group 'ess  
+    :type  'string
+)
+
+(defcustom ess-kermit-prefix "#"
+    "*String files must begin with to use kermit file transfer."
+    :group 'ess  
+    :type  'string
+)
+
+(defcustom ess-kermit-remote-directory "$HOME"
+    "*Buffer local variable that designates remote directory of file."
+    :group 'ess  
+    :type  'string
+)
+
+(make-variable-buffer-local 'ess-kermit-remote-directory)
+
 ;;*;; Regular expressions
 
 ;; FIXME : This is just for the S dialects;  need to define this for others,
@@ -627,8 +671,9 @@ in S+4 Commands window and in Sqpe+4 buffer."
   :group 'ess-S
   :type 'string)
 
-(defcustom inferior-Sqpe+4-SHOME-name 
-  (if ess-microsoft-p "c:/progra~1/spls45se" nil)
+;;; SJE - avoid mismatch by changing default nil to ""
+(defcustom inferior-Sqpe+4-SHOME-name
+  (if ess-microsoft-p "c:/progra~1/spls45se" "")
   "*SHOME name for invoking an inferior ESS with Sqpe+4().
 The default value is correct for a default installation of
 S-Plus 4.5 Student Edition.  For any other version or location,
@@ -708,8 +753,9 @@ in S+6 for Windows Commands window and in Sqpe+6 for Windows buffer."
   :group 'ess-S
   :type 'string)
 
+;;; SJE - avoid mismatch by changing default nil to ""
 (defcustom inferior-Sqpe+6-SHOME-name
-  (if ess-microsoft-p "c:/progra~1/insigh~1/splus6" nil)
+  (if ess-microsoft-p "c:/progra~1/insigh~1/splus6" "")
   "*SHOME name for invoking an inferior ESS with Sqpe+6() for Windows.
 The default value is correct for a default installation of
 S-Plus 6.0.3 Release 2.  For any other version or location,
@@ -750,7 +796,7 @@ version of the pathname."
 
 (defcustom inferior-SAS-program-name "sas"
   "*Program name for invoking an inferior ESS with SAS()."
-  :group 'ess-SAS
+  :group 'ess-sas
   :type 'string)
 
 (defcustom inferior-STA-program-name "env"
@@ -779,34 +825,34 @@ order for it to work right.  And Emacs is too smart for it."
 ;;; These variables are currently used only with the S language files for
 ;;; S S-Plus R.
 
-(defcustom R-editor 
+(defcustom R-editor
   (if ess-microsoft-p "gnuclient.exe"
     (if (equal system-type 'Apple-Macintosh) nil
-      "emacslient")) ;; unix
+      "emacsclient")) ;; unix
   "*Editor called by R process with 'edit()' command."
 :group 'ess
-:type "string")
+:type 'string)
 
-(defcustom R-pager  nil ; Usually nil is correct as ESS and page() cooperate.
+(defcustom R-pager 'nil ; Usually nil is correct as ESS and page() cooperate.
   "*Pager called by R process with 'page()' command."
 :group 'ess
-:type "string")
+:type 'string)
 
 (defcustom S-editor
   (if ess-microsoft-p "gnuclient.exe"
     (if (equal system-type 'Apple-Macintosh) nil
-      "emacslient")) ;; unix
+      "emacsclient")) ;; unix
   "*Editor called by S process with 'edit()' command."
 :group 'ess
-:type "string")
+:type 'string)
 
 (defcustom S-pager
   (if ess-microsoft-p "gnuclientw.exe"
     (if (equal system-type 'Apple-Macintosh) nil
-      "emacslient")) ;; unix
+      "emacsclient")) ;; unix
   "*Pager called by S process with 'page()' command."
 :group 'ess
-:type "string")
+:type 'string)
 
 (defcustom ess-editor nil
   "*Editor by which the process sends information to an emacs buffer
@@ -879,7 +925,7 @@ Useful for R and SAS.  This is generic."
 (defcustom inferior-ess-start-file nil
   "*File dumped into process, if non-nil."
   :group 'ess-proc
-  :type 'file)
+  :type '(choice (const nil) file))
 
 (defcustom inferior-ess-pager "cat"
   "*Pager to use for reporting help files and similar things."
@@ -937,6 +983,8 @@ of Emacs until the code has been successfully evaluated."
   :group 'ess-proc
   :type 'boolean)
 
+;;; SJE - suggest this is not defcustom, looks like each mode sets this.
+;;; SJE - this still produces mismatch.
 (defcustom ess-save-lastvalue-command nil
   "Default depends on the ESS language/dialect.
 
@@ -949,6 +997,8 @@ Might have to:"
   :group 'ess-command
   :type 'string)
 
+;;; SJE - suggest this is not defcustom, looks like each mode sets this.
+;;; SJE - this still produces mismatch.
 (defcustom ess-retr-lastvalue-command nil
   "Default is currently the S+ version."
   :group 'ess-command
@@ -965,7 +1015,7 @@ Might have to:"
 (defcustom ess-current-process-name nil
   "Name of the current S process."
   :group 'ess-proc
-  :type 'string)
+  :type '(choice (const nil) string))
 
 ;; defconst ess-local-process-name now done in S.el
 
@@ -1050,7 +1100,7 @@ Don't include a newline at the end! Used in ess-execute-objects."
  Constructed at run time from `inferior-ess-primary-prompt' and
 `inferior-ess-secondary-prompt'."
   :group 'ess-proc
-  :type 'string)
+  :type '(choice (const nil) string))
 
 (make-variable-buffer-local 'inferior-ess-prompt)
 
