@@ -8,9 +8,9 @@
 ;;         (now: dsmith@insightful.com)
 ;; Maintainer: A.J. Rossini <rossini@u.washington.edu>
 ;; Created: 7 Jan 1994
-;; Modified: $Date: 2002/01/21 03:19:41 $
-;; Version: $Revision: 5.75 $
-;; RCS: $Id: ess-inf.el,v 5.75 2002/01/21 03:19:41 rmh Exp $
+;; Modified: $Date: 2002/06/20 21:52:06 $
+;; Version: $Revision: 5.78 $
+;; RCS: $Id: ess-inf.el,v 5.78 2002/06/20 21:52:06 rsparapa Exp $
 
 ;; This file is part of ESS
 
@@ -929,7 +929,7 @@ On success, return 0.  Otherwise, go as far as possible and return -1."
       (setq arg (- arg inc)))
     n))
 
-(defun ess-eval-line-and-step (&optional simple-next even-empty)
+(defun ess-eval-line-and-step (&optional simple-next even-empty invisibly)
   "Evaluate the current line visibly and step to the \"next\" line.
 \"next\" = the next line with non-comment code _unless_ SIMPLE-NEXT is non-nil,
 possibly via prefix arg.  If 2nd arg EVEN-EMPTY [prefix as well],
@@ -944,11 +944,16 @@ both SIMPLE-NEXT and EVEN-EMPTY are interpreted as true."
       (beginning-of-line)
       ;; go to end of process buffer so user can see result
       (ess-eval-linewise (buffer-substring (point) end)
-			 nil 'eob (or even-empty ess-eval-empty))))
+			 invisibly 'eob (or even-empty ess-eval-empty))))
   (if (or simple-next ess-eval-empty)
       (forward-line 1)
     (ess-next-code-line 1)))
 
+(defun ess-eval-line-and-step-invisibly (&optional simple-next even-empty)
+   "Evaluate the current line invisibly and step to the next line.
+Evaluate all comments and empty lines."
+  (interactive)
+  (ess-eval-line-and-step t t t))
 
 ;; goes to the real front, in case you do double function definition
 ;; 29-Jul-92 -FER
@@ -1058,11 +1063,11 @@ process buffer. Arg has same meaning as for `ess-eval-region'."
 (if inferior-ess-mode-map
     nil
 
-  (cond (ess-running-xemacs
+  (cond ((featurep 'xemacs)
 	 ;; Code for XEmacs
 	 (setq inferior-ess-mode-map (make-keymap))
 	 (set-keymap-parent inferior-ess-mode-map comint-mode-map))
-	((not ess-running-xemacs)
+	((not (featurep 'xemacs))
 	 ;; Code for GNU Emacs
 	 (setq inferior-ess-mode-map (cons 'keymap comint-mode-map))))
 
@@ -1126,12 +1131,12 @@ process buffer. Arg has same meaning as for `ess-eval-region'."
 
 (if ess-mode-minibuffer-map  nil
 
-  (cond (ess-running-xemacs
+  (cond ((featurep 'xemacs)
 	 ;; Code for XEmacs
 	 (setq ess-mode-minibuffer-map (make-keymap))
 	 (set-keymap-parent ess-mode-minibuffer-map minibuffer-local-map)))
 
-  (cond ((not ess-running-xemacs)
+  (cond ((not (featurep 'xemacs))
 	 ;; Code for Emacs
 	 (setq ess-mode-minibuffer-map (cons 'keymap minibuffer-local-map))))
 
@@ -1522,17 +1527,21 @@ to the command if BUFF is not given.)"
   (interactive)
   (ess-force-buffer-current "Process to quit: ")
   (ess-make-buffer-current)
-  ;; This needs to be modified to handle R, sigh...
+  ;;  Modified to handle R (rmh 2002 Mar 12)
   (let ((sprocess (get-ess-process ess-current-process-name)))
     (if (not sprocess) (error "No ESS process running."))
-    (if (yes-or-no-p (format "Really quit ESS (process %s)" sprocess))
-	;; or %S above?
-	(save-excursion
+    (if (yes-or-no-p (format "Really quit ESS process %s? " sprocess))
+	(progn   ;;;;previouslyl (save-excursion
 	  (ess-cleanup)
 	  (ess-switch-to-ESS nil)
 	  (goto-char (marker-position (process-mark sprocess)))
 	  (insert inferior-ess-exit-command)
-	  (process-send-string sprocess inferior-ess-exit-command)
+	  (if (string-equal ess-dialect "R")
+	      (progn
+		(inferior-ess-send-input)
+		(setq inferior-ess-prompt inferior-ess-exit-prompt)
+		(inferior-ess-wait-for-prompt))
+	    (process-send-string sprocess inferior-ess-exit-command))
 	  (rename-buffer (concat (buffer-name) "-exited") t)))))
 
 (defun ess-abort ()
