@@ -4,9 +4,9 @@
 ;; Author: Richard M. Heiberger  <rmh@fisher.stat.temple.edu>
 ;; Maintainer: A.J. Rossini <rossini@biostat.washington.edu>
 ;; Created: 9 Dec 1998
-;; Modified: $Date: 2002/01/03 08:46:10 $
-;; Version: $Revision: 1.15 $
-;; RCS: $Id: ess-iw32.el,v 1.15 2002/01/03 08:46:10 maechler Exp $
+;; Modified: $Date: 2002/03/03 21:59:52 $
+;; Version: $Revision: 1.17 $
+;; RCS: $Id: ess-iw32.el,v 1.17 2002/03/03 21:59:52 rmh Exp $
 
 
 ;; This file is part of ESS
@@ -292,6 +292,10 @@ save the output in that buffer. BUF is erased before use.
 COM should have a terminating newline.
 Guarantees that the value of .Last.value will be preserved."
   (interactive)
+  (if buf                ;;Mar 01 2002 rmh
+      (save-excursion
+	(set-buffer buf)
+	(setq ess-local-process-name ess-current-process-name)))
   (if (not (ess-ddeclient-p))
       (ess-command-original com buf)
     (ess-force-buffer-current "Process to load into: ")
