@@ -7,9 +7,9 @@
 ;; Author: David Smith <D.M.Smith@lancaster.ac.uk>
 ;; Maintainer: A.J. Rossini <rossini@biostat.washington.edu>
 ;; Created: 12 Nov 1993
-;; Modified: $Date: 2002/01/21 03:21:26 $
-;; Version: $Revision: 5.86 $
-;; RCS: $Id: ess-site.el,v 5.86 2002/01/21 03:21:26 rmh Exp $
+;; Modified: $Date: 2002/06/19 21:00:20 $
+;; Version: $Revision: 5.90 $
+;; RCS: $Id: ess-site.el,v 5.90 2002/06/19 21:00:20 rmh Exp $
 ;;
 ;; Keywords: start up, configuration.
 
@@ -150,7 +150,7 @@ The extension, in a file name, is the part that follows the last `.'."
 	          (substring file 0 (match-beginning 0)))
 	      filename)))))
 
-  (add-to-list 'load-path ess-lisp-directory)
+  (add-to-list 'load-path (file-name-as-directory ess-lisp-directory))
 
   ;; Need these as early as here [also in ./ess-comp.el] :
   (if (not (boundp 'ess-show-load-messages))
@@ -302,11 +302,21 @@ The extension, in a file name, is the part that follows the last `.'."
 ;;(setq-default inferior-Sqpe+6-SHOME-name "c:/progra~1/Insightful/SPLUS6")
 ;;(setq-default inferior-Sqpe+6-program-name "c:/progra~1/Insightful/SPLUS6/cmd/Sqpe.exe")
 
-;;; These ddeclient values will be buffer-local on WS-Windows 9x/NT
+;;; These ddeclient values will be buffer-local on MS-Windows 9x/NT
 (setq-default inferior-ess-ddeclient	     "Initial")
 (setq-default inferior-ess-client-name	     "Initial")
 (setq-default inferior-ess-client-command    "Initial")
 
+;;; S-Plus 6 for Windows startup time depends on the amount of RAM and
+;;; the processor speed.  ESS needs to build a delay into the M-x S+6
+;;; sequence to allow time for S-Plus 6 to open the Commands window.
+;;; We then send several lines to the Commands window before returning
+;;; control to the user.  On a 300 MHz machine with 96MB of RAM the
+;;; delay is 60 seconds.  On a ???? MHz machine with 523MB the delay is
+;;; 10 seconds.  The user may need to adjust this number.
+(defvar ess-S+6-startup-delay 60
+"*Number of seconds to wait for the Commands window to appear before
+sending `inferior-ess-language-start' to S-Plus.")
 
 
 ;;; see essd-els.el
@@ -416,7 +426,7 @@ The extension, in a file name, is the part that follows the last `.'."
 (autoload 'ess-transcript-mode "ess-trns"
   "Major mode for editing S transcript files." t)
 
-;;; On a PC, the default is S+6.  
+;;; On a PC, the default is S+6.
 ;; Elsewhere (unix and linux) the default is S+6
 (cond (ess-microsoft-p ; MS-Windows
        (fset 'S 'S+6)
@@ -571,7 +581,7 @@ The extension, in a file name, is the part that follows the last `.'."
 ;;;   1c. You can also define C-TAB in all modes by specifying either
 ;;;(setq ess-sas-global-unix-keys t) ;; optional C-TAB bound in all modes
 ;;;(setq ess-sas-global-pc-keys t)   ;; optional C-TAB bound in all modes
-;;;       See below. 
+;;;       See below.
 ;;;
 ;;;   2. Managing submitted SAS jobs with function keys.
 ;;;   2a. Default: Function keys retain their global bindings.
@@ -585,9 +595,9 @@ The extension, in a file name, is the part that follows the last `.'."
 ;;;      in same-window-buffer-names, then uncomment the following line
 ;;;(ess-same-window-async)
 ;;;
-;;;   4. As of 5.1.19, a new and improved syntax highlighting scheme for .sas and .log 
+;;;   4. As of 5.1.19, a new and improved syntax highlighting scheme for .sas and .log
 ;;;	 files is available (press f10 to toggle between modes in .log).  If you are
-;;;      using XEmacs v. 20.x, then you need this as well, since it works around a 
+;;;      using XEmacs v. 20.x, then you need this as well, since it works around a
 ;;;      problem with make-regexp.el.  Uncomment the next line for this feature:
 ;;;(setq ess-sas-run-make-regexp nil)
 
