@@ -1,15 +1,15 @@
 ;;; essa-sas.el -- ESS local customizations for SAS, part a.
 
-;; Copyright (C) 1997--2001 Rodney Sparapani, A.J. Rossini, 
+;; Copyright (C) 1997--2002 Rodney A. Sparapani, A.J. Rossini, 
 ;; Martin Maechler, Kurt Hornik, and Richard M. Heiberger.
 
-;; Author: Rodney Sparapani <rsparapa@mcw.edu>
-;; Maintainer: Rodney Sparapani <rsparapa@mcw.edu>, 
+;; Author: Rodney A. Sparapani <rsparapa@mcw.edu>
+;; Maintainer: Rodney A. Sparapani <rsparapa@mcw.edu>, 
 ;;             A.J. Rossini <rossini@u.washington.edu>
 ;; Created: 17 November 1999
-;; Modified: $Date: 2002/02/07 17:14:55 $
-;; Version: $Revision: 1.82 $
-;; RCS: $Id: essa-sas.el,v 1.82 2002/02/07 17:14:55 rsparapa Exp $
+;; Modified: $Date: 2002/07/25 16:33:21 $
+;; Version: $Revision: 1.114 $
+;; RCS: $Id: essa-sas.el,v 1.114 2002/07/25 16:33:21 rsparapa Exp $
 
 ;; Keywords: ESS, ess, SAS, sas, BATCH, batch 
 
@@ -43,20 +43,33 @@
 
 ;;; Section 1:  Variable Definitions
 
-;;(require 'ess-batch)
-
-(defcustom ess-kermit-command "gkermit -T"
-    "*Kermit command invoked by `ess-kermit-get' and `ess-kermit-send'."
-    :group 'ess-sas
-    :type  'string
-)
-
 (defvar ess-sas-file-path "."
     "Full path-name of the sas file to perform operations on.")
 
 (defcustom ess-sas-data-view-libname " "
     "*SAS code to define a library for `ess-sas-data-view'."
-    :group 'ess-sas
+    :group 'ess-sas  
+    :type  'string
+)
+
+(defcustom ess-sas-data-view-fsview-command "; proc fsview data=" 
+    "*SAS code to open a SAS dataset with `ess-sas-data-view'."
+    :group 'ess-sas  
+    :type  'string
+)
+
+(defcustom ess-sas-data-view-fsview-statement " "
+    "*SAS code to perform a PROC FSVIEW statement with `ess-sas-data-view'."
+    :group 'ess-sas  
+    :type  'string
+)
+
+(make-variable-buffer-local 'ess-sas-data-view-fsview-statement)
+
+(defcustom ess-sas-graph-suffix-regexp 
+    "[.]\\([eE]?[pP][sS]\\|[gG][iI][fF]\\|[jJ][pP][eE]?[gG]\\|[tT][iI][fF][fF]?\\)"
+    "*GSASFILE suffix regexp."
+    :group 'ess-sas  
     :type  'string
 )
 
@@ -65,9 +78,24 @@
 ;;    :group 'ess-sas
 ;;)
 
+(defcustom ess-sas-shell-buffer "*shell*"
+"*Name that you want to use for the shell buffer; buffer-local."
+    :group 'ess-sas
+    :type  'string
+)
+
+(make-variable-buffer-local 'ess-sas-shell-buffer)
+
+(defcustom ess-sas-submit-mac-virtual-pc nil
+"*Non-nil means that you want to run Windows SAS in a
+Virtual PC emulator on your Mac; buffer-local."
+    :group 'ess-sas)
+
+(make-variable-buffer-local 'ess-sas-submit-mac-virtual-pc)
+
 (defcustom ess-sas-submit-command sas-program
     "*Command to invoke SAS in batch; buffer-local."
-    :group 'ess-sas
+    :group 'ess-sas  
     :type  'string
 )
 
@@ -75,7 +103,7 @@
 
 (defcustom ess-sas-submit-command-options " "
     "*Options to pass to SAS in batch; buffer-local."
-    :group 'ess-sas
+    :group 'ess-sas  
     :type  'string
 )
 
@@ -84,31 +112,42 @@
 (defvar ess-sas-submit-method 
   (if ess-microsoft-p 
     (if (w32-shell-dos-semantics) 'ms-dos 'sh)
-    (if (equal system-type 'Apple-Macintosh) 'apple-script 'sh))
-  "Method used by `ess-sas-submit'.
+    (if (or (equal system-type 'Apple-Macintosh) 
+	    (and ess-sas-submit-mac-virtual-pc (equal system-type 'darwin)))
+	'apple-script 'sh))
+"Method used by `ess-sas-submit'.
 The default is based on the value of the emacs variable `system-type'
-and, on Windows machines, the function `w32-shell-dos-semantics'.
-'ms-dos           if *shell* follows MS-DOS semantics
-'iESS             inferior ESS, may be local or remote
+and, on Windows, the function `w32-shell-dos-semantics'.
 'sh               if *shell* runs sh, ksh, csh, tcsh or bash
-'apple-script     *shell* unavailable, use AppleScript
+'ms-dos           if *shell* follows MS-DOS semantics
+'apple-script     *shell* unavailable in Mac Classic, use AppleScript,
+                  also for Windows SAS in Virtual PC on Mac OS X 
 
-Windows users running MS-DOS in *shell* will get 'ms-dos by default.
+Unix users will get 'sh by default.  
 
 Windows users running bash in *shell* will get 'sh by default.
 
-Unix users will get 'sh by default.
+Windows users running MS-DOS in *shell* will get 'ms-dos by default.
 
-Users accessing a remote machine with `telnet', `rlogin', `ssh',
-or `ESS-elsewhere' should have one of the following in ~/.emacs
-   (setq-default ess-sas-submit-method 'iESS)
-   (setq-default ess-sas-submit-method 'sh)")
+Users accessing a remote machine with `telnet', `rlogin', `ssh', etc.,
+should set this variable to 'sh regardless of their local shell 
+(since their remote shell is 'sh).")
 
-(defcustom ess-sas-data-view-options 
+(make-variable-buffer-local 'ess-sas-submit-method)
+
+(defcustom ess-sas-data-view-submit-options 
     (if ess-microsoft-p "-noenhancededitor -nosysin -log NUL:"
 	"-nodms -nosysin -log /dev/null")
     "*The options necessary for your enviromment and your operating system."
-    :group 'ess-sas
+    :group 'ess-sas  
+    :type  'string
+)
+
+(defcustom ess-sas-image-viewer
+    (if ess-microsoft-p "kodakimg" 
+	(if (equal ess-sas-submit-method 'sh) "sdtimage"))
+    "*Application to view GSASFILE."
+    :group 'ess-sas  
     :type  'string
 )
 
@@ -116,7 +155,7 @@ or `ESS-elsewhere' should have one of the following in ~/.emacs
     (if (equal ess-sas-submit-method 'sh) "-rsasuser &" 
 	(if ess-microsoft-p "-rsasuser -icon"))    
     "*Command-line statement to post-modify SAS invocation, e.g. -rsasuser"
-    :group 'ess-sas
+    :group 'ess-sas  
     :type  'string
 )
 
@@ -124,19 +163,19 @@ or `ESS-elsewhere' should have one of the following in ~/.emacs
     (if (equal ess-sas-submit-method 'sh) "nohup" 
 	(if ess-microsoft-p "start"))
     "*Command-line statement to pre-modify SAS invocation, e.g. start or nohup"
-    :group 'ess-sas
+    :group 'ess-sas  
     :type  'string
 )
 
 (defcustom ess-sas-suffix-1 "txt"
     "*The first suffix to associate with SAS."
-    :group 'ess-sas
+    :group 'ess-sas  
     :type  'string
 )
 
 (defcustom ess-sas-suffix-2 "dat"
     "*The second suffix to associate with SAS."
-    :group 'ess-sas
+    :group 'ess-sas  
     :type  'string
 )
 
@@ -148,13 +187,14 @@ or `ESS-elsewhere' should have one of the following in ~/.emacs
 	    "\\|" (downcase ess-sas-suffix-2) "\\|" (upcase ess-sas-suffix-2)))
 	"\\)")
     "*Regular expression for SAS suffixes."
-    :group 'ess-sas
+    :group 'ess-sas  
     :type  'string
 )
 
-(defcustom ess-sleep-for 5
-    "*Default for ess-sas-submit-sh is to sleep for 5 seconds."
-    :group 'ess-sas
+(defcustom ess-sleep-for (if ess-microsoft-p 5 0)
+"*`ess-sas-submit-sh' may need to pause before sending output 
+to the shell on Windows when `ess-sas-submit-method' is 'sh."
+    :group 'ess-sas  
     :type  'number
 )
 
@@ -164,7 +204,7 @@ or `ESS-elsewhere' should have one of the following in ~/.emacs
 
 (defcustom ess-sas-temp-root "ess-temp"
     "*The root of the temporary .sas file for `ess-sas-submit-region'."
-    :group 'ess-sas
+    :group 'ess-sas  
     :type  'string
 )
 
@@ -184,63 +224,12 @@ buffer on the local computer."
 
 
 (defun ess-exit-notify-sh (string)
-  "Detect completion or failure of submitted job and notify the user."
+"Detect completion or failure of submitted job and notify the user."
   (let* ((exit-done "\\[[0-9]+\\]\\ *\\+*\\ *\\(Exit\\|Done\\).*$")
 	 (beg (string-match exit-done string)))
     (if beg
 	(message (substring string beg (match-end 0))))))
 
-(defun ess-kermit-get ()
-  "Get a file with Kermit.  Works so far with ssh, but not telnet."
-    (interactive)
-
-     (save-match-data 
-       (let ((ess-temp-file (expand-file-name (buffer-name))))
-     
-	(if (and (not (string-match "[[]" ess-temp-file))
-	  (string-match "]" ess-temp-file)) (progn
-
-	  (setq ess-temp-file (substring ess-temp-file (match-end 0)))
-	  (shell)
-	  (insert "cd $HOME; " ess-kermit-command " -s " ess-temp-file " -a ]" ess-temp-file)
-          (comint-send-input)	
-;;          (insert (read-string "Press Return to connect to Kermit: " nil nil "\C-\\c"))
-;;	  (comint-send-input)
-;;	  (insert (read-string "Press Return when Kermit is ready to recieve: " nil nil 
-;;		  (concat "receive ]" ess-sas-temp-file)))                
-;;	  (comint-send-input)
-;;	  (insert (read-string "Press Return when transfer is complete: " nil nil "c"))                
-;;	  (comint-send-input)
-          (insert (read-string "Press Return when shell is ready: "))
-	  (comint-send-input)
-	  (switch-to-buffer (find-buffer-visiting (concat "]" ess-temp-file)))
-	  (ess-revert-wisely)
-)))))
-
-(defun ess-kermit-send ()
-  "Send a file with Kermit.  Works so far with ssh, but not telnet."
-    (interactive)
-
-     (save-match-data (let ((ess-temp-file (expand-file-name (buffer-name))))
-	(if (and (not (string-match "[[]" ess-temp-file))
-	  (string-match "]" ess-temp-file)) (progn
-
-	  (setq ess-temp-file (substring ess-temp-file (match-end 0)))
-             (save-buffer)
-	     (shell)
-	     (insert "cd $HOME; " ess-kermit-command " -g ]" ess-temp-file " -a " ess-temp-file)
-             (comint-send-input)	
-;;	     (insert (read-string "Press Return to connect to Kermit: " nil nil "\C-\\c"))
-;;	     (comint-send-input)
-;;	     (insert (read-string "Press Return when Kermit is ready to send: " nil nil
-;;		     (concat "send ]" ess-sas-temp-file " " ess-sas-temp-file)))                
-;;	     (comint-send-input)
-;;	     (insert (read-string "Press Return when transfer is complete: " nil nil "c"))              
-;;           (comint-send-input)
-             (insert (read-string "Press Return when shell is ready: "))
-	     (comint-send-input)
-	     (switch-to-buffer (find-buffer-visiting (concat "]" ess-temp-file)))
-)))))
 
 
 (defun ess-sas-append-log ()
@@ -338,40 +327,89 @@ on the way."
 (defun ess-sas-data-view (&optional ess-sas-data)
   "Open a dataset for viewing with PROC FSVIEW."
     (interactive)
+    (ess-save-and-set-local-variables)
+
+ (save-excursion (let ((ess-tmp-sas-data nil) 
+    (ess-tmp-sas-data-view-fsview-statement ess-sas-data-view-fsview-statement)
+    (ess-search-regexp "[ \t=]\\([a-zA-Z_][a-zA-Z_0-9]*[.][a-zA-Z_][a-zA-Z_0-9]*\\)\\(&.*\\)?[ ,()\t;]")
+    (ess-search-except "^\\([wW][oO][rR][kK]\\|[fF][iI][rR][sS][tT]\\|[lL][aA][sS][tT]\\)[.]"))
 
- (save-excursion (let ((ess-tmp-sas-data nil))
     (if ess-sas-data nil (save-match-data 
-       (search-backward-regexp "[ \t=]" nil t)
+	(search-backward-regexp "[ \t=]" nil t)
 
-       (if (or
-           (search-forward-regexp 
-	     "[ \t=]\\([a-zA-Z_][a-zA-Z_0-9]*[.][a-zA-Z_][a-zA-Z_0-9]*\\)[ ,()\t;]"
-	     nil t)
-           (search-backward-regexp 
-	     "[ \t=]\\([a-zA-Z_][a-zA-Z_0-9]*[.][a-zA-Z_][a-zA-Z_0-9]*\\)[ ,()\t;]"
-	     nil t)) (setq ess-tmp-sas-data (match-string 1)))
+        (save-excursion 
+	    (setq ess-tmp-sas-data (ess-search-except ess-search-regexp ess-search-except)))
 
-       (if (and ess-tmp-sas-data 
-	  (not (string-match "^\\(first\\|last\\)[.]" ess-tmp-sas-data)))
-	    (setq ess-sas-data (read-string "SAS Dataset: " ess-tmp-sas-data))
-	    (setq ess-sas-data (read-string "SAS Dataset: ")))
+        (if (not ess-tmp-sas-data) 
+	    (setq ess-tmp-sas-data (ess-search-except ess-search-regexp ess-search-except t)))
 
-       (if (get-buffer "*shell*") (set-buffer "*shell*") (shell))
+	(setq ess-sas-data (read-string "Permanent SAS Dataset: " ess-tmp-sas-data))
+
+        (ess-sas-goto-shell t)
 
 	(insert (concat ess-sas-submit-pre-command " " ess-sas-submit-command 
-	    " -initstmt \"" ess-sas-data-view-libname "; proc fsview data=" 
-	    ess-sas-data "; run;\" " ess-sas-data-view-options " " 
-	    ess-sas-submit-post-command))
+	    " -initstmt \"" ess-sas-data-view-libname ess-sas-data-view-fsview-command 
+	    ess-sas-data ";" ess-tmp-sas-data-view-fsview-statement "; run;\" " 
+	    ess-sas-data-view-submit-options " " ess-sas-submit-post-command))
     (comint-send-input)
 )))))
 
+(defun ess-sas-graph-view ()
+  "Open a GSASFILE for viewing."
+  (interactive)
+  (ess-sas-file-path)
+
+  (save-excursion (let ((ess-tmp-sas-graph nil)
+        (ess-tmp-sas-glyph nil)
+        (ess-tmp-sas-graph-regexp (concat "['\"]\\(.*" ess-sas-graph-suffix-regexp "\\)['\"]")))
+
+    (save-match-data 
+       (search-backward-regexp "[ \t=]" nil t)
+
+       (save-excursion 
+	    (setq ess-tmp-sas-graph (ess-search-except ess-tmp-sas-graph-regexp)))
+
+        (if (not ess-tmp-sas-graph) 
+	    (setq ess-tmp-sas-graph (ess-search-except ess-tmp-sas-graph-regexp nil t)))
+
+	(setq ess-tmp-sas-graph (read-string "GSASFILE: " 
+	    (or ess-tmp-sas-graph (file-name-nondirectory ess-sas-file-path))))
+
+	    (setq ess-tmp-sas-graph    (convert-standard-filename 
+			(concat (file-name-directory ess-sas-file-path) "/" ess-tmp-sas-graph)))
+
+	  (if (fboundp 'ess-xemacs-insert-glyph) (progn
+	      (if (string-match "[.][gG][iI][fF]" ess-tmp-sas-graph)
+		 (setq ess-tmp-sas-glyph 'gif)
+	      ;;else
+	      (if (string-match "[.][jJ][pP][eE]?[gG]" ess-tmp-sas-graph)
+		 (setq ess-tmp-sas-glyph 'jpeg)))))
+
+	  (if ess-tmp-sas-glyph (progn
+		(switch-to-buffer (file-name-nondirectory ess-tmp-sas-graph))
+		(ess-xemacs-insert-glyph (make-glyph (vector ess-tmp-sas-glyph :file ess-tmp-sas-graph)))
+	     )
+	  ;;else
+	  (if (and (boundp 'auto-image-file-mode) auto-image-file-mode
+	      (string-match "[.][jJ][pP][eE]?[gG]" ess-tmp-sas-graph))
+	      (find-file ess-tmp-sas-graph)
+          ;;else
+         
+            (ess-sas-goto-shell t)
+
+            (insert ess-sas-submit-pre-command " " ess-sas-image-viewer " " ess-tmp-sas-graph 
+	      (if (equal ess-sas-submit-method 'sh) " &"))
+            (comint-send-input))
+)))))
+
 (defun ess-sas-file-path ()
- "*Set `ess-sas-file-path' depending on suffix."
+ "Define `ess-sas-file-path' to be the current buffer depending on suffix."
   (interactive)
 
-  (save-match-data (let ((ess-temp-file (expand-file-name (buffer-name))))
-    (if (string-match ess-sas-suffix-regexp ess-temp-file)
-        (setq ess-sas-file-path (nth 0 (split-string ess-temp-file "[<]")))))))
+  (save-match-data (let ((ess-sas-temp-file (expand-file-name (buffer-name))))
+    (if (string-match ess-sas-suffix-regexp ess-sas-temp-file) ;;(progn
+	(setq ess-sas-file-path (nth 0 (split-string ess-sas-temp-file "[<]")))))))
+	;; (setq ess-directory (file-name-directory ess-sas-file-path)))))))
 
 (defun ess-sas-goto (suffix &optional revert)
   "Find a file associated with a SAS file by suffix and revert if necessary."
@@ -388,10 +426,13 @@ on the way."
 		(ess-sas-temp-file (replace-match (concat "." suffix) t t ess-sas-file-path))
 		(ess-sas-temp-buff (find-buffer-visiting ess-sas-temp-file)))
 
-	(if ess-sas-temp-buff (switch-to-buffer ess-sas-temp-buff)
-	    (find-file ess-sas-temp-file))
+	    (if ess-sas-temp-buff (switch-to-buffer ess-sas-temp-buff)
+	        (find-file ess-sas-temp-file))
 	
-	  (if revert (ess-revert-wisely))
+	    (if revert (ess-revert-wisely))
+
+	    (if (or (string-equal suffix "log") (string-equal suffix "lst"))
+		(ess-kermit-get (file-name-nondirectory ess-sas-temp-file)))
 ))))))
 
 ;;(defun ess-sas-file (suffix &optional revert)
@@ -411,13 +452,6 @@ on the way."
 ;;	    (switch-to-buffer ess-sas-buf)
 ;;	    (if revert (ess-revert-wisely))))))
 
-(defun ess-sas-file-path ()
- "Define the variable `ess-sas-file-path' to be the file in the current buffer"
-  (interactive)
-
-  (save-match-data (let ((ess-sas-temp-file (expand-file-name (buffer-name))))
-    (if (string-match ess-sas-suffix-regexp ess-sas-temp-file) 
-	(setq ess-sas-file-path (nth 0 (split-string ess-sas-temp-file "[<]")))))))
 
 (defun ess-sas-goto-file-1 ()
   "Switch to ess-sas-file-1 and revert from disk."
@@ -461,13 +495,24 @@ on the way."
   (interactive)
   (ess-sas-goto "sas" revert))
 
-;;
-;;(defun ess-sas-goto-shell ()
-;; "Set variable `ess-sas-file-path' to file in current buffer and goto *shell*"
-;;  (interactive)
-;;  (ess-sas-file-path)
-;;  (switch-to-buffer "*shell*")
-;;)
+(defun ess-sas-goto-shell (&optional set-buffer)
+"Set `ess-sas-file-path' and goto `ess-sas-shell-buffer'.  If
+optional argument is non-nil, then set-buffer rather than switch."
+  (interactive)
+  (ess-sas-file-path)
+
+  (if (get-buffer ess-sas-shell-buffer) 
+    (if set-buffer (set-buffer ess-sas-shell-buffer) (switch-to-buffer ess-sas-shell-buffer))
+    (let ((temp-shell-buffer ess-sas-shell-buffer))
+    (shell)
+    (rename-buffer temp-shell-buffer)
+
+    (if (eq ess-sas-submit-method 'sh)
+	(add-hook 'comint-output-filter-functions 'ess-exit-notify-sh)) ;; 19.28
+                                          ;; nil t) works for newer emacsen
+    )
+  )
+)
 
 (defun ess-sas-submit ()
   "Save the .sas file and submit to shell using a function that
@@ -475,13 +520,6 @@ depends on the value of  `ess-sas-submit-method'"
   (interactive)
   (ess-sas-file-path)
   (ess-sas-goto-sas)
-  (save-buffer)
-
-  ; if Local Variables are defined, a revert is necessary to update their values
-  (save-excursion 
-    (beginning-of-line -1)
-    (save-match-data 
-	(if (search-forward "End:" nil t) (revert-buffer t t))))
 
   (cond
    ((eq ess-sas-submit-method 'apple-script) 
@@ -493,7 +531,7 @@ depends on the value of  `ess-sas-submit-method'"
    ((eq ess-sas-submit-method 'sh) 
 	(ess-sas-submit-sh ess-sas-submit-command ess-sas-submit-command-options)) 
    (t (ess-sas-submit-sh ess-sas-submit-command ess-sas-submit-command-options)))
-  (ess-sas-goto-sas)
+;  (ess-sas-goto-sas)
 )
 
 (defun ess-sas-submit-iESS (arg1 arg2)
@@ -516,13 +554,17 @@ their files from the remote computer.  Local copies of the .sas .lst
   (ess-eval-linewise (concat arg1 " " arg2 " " (buffer-name) " &")))
 
 (defun ess-sas-submit-mac (arg1 arg2)
-  "Mac
-arg1 is assumed to be the AppleScript command
-\"invoke SAS using program file\".  If so, then arg2, if any, is a complex string
-of the form \"with options { \\\"option-1\\\", \\\"option-2\\\", etc.}\" ."
-  (do-applescript (concat arg1
-			  " \"" (unix-filename-to-mac default-directory)
-			  (buffer-name) "\"" arg2)))
+"If you are using Mac SAS, then arg1, `ess-sas-submit-command', should be 
+the AppleScript command \"invoke SAS using program file\", and, if necessary,
+arg2, `ess-sas-submit-command-options', is a string of the form 
+\"with options { \\\"option-1\\\", \\\"option-2\\\", etc.}\".  If you are
+using Windows SAS with the PC emulator Virtual PC, then `ess-sas-submit-command'
+should be ..."
+  (ess-save-and-set-local-variables)
+
+  (do-applescript (concat arg1 " \""
+     (if (not ess-sas-submit-mac-virtual-pc) (unix-filename-to-mac default-directory))
+	(buffer-name) "\"" arg2)))
 
 (defun ess-sas-submit-region ()
     "Write region to temporary file, and submit to SAS."
@@ -532,7 +574,7 @@ of the form \"with options { \\\"option-1\\\", \\\"option-2\\\", etc.}\" ."
 	(concat ess-sas-temp-root ".sas"))
 
     (save-excursion 
-      (if (get-buffer "*shell*") (set-buffer "*shell*") (shell))
+      (ess-sas-goto-shell t)
 
     (if (and (w32-shell-dos-semantics)
 	(string-equal ":" (substring ess-sas-file-path 1 2)))
@@ -558,15 +600,31 @@ SAS may not be found in your PATH.  You can alter your PATH to include
 SAS or you can specify the PATHNAME (PATHNAME can NOT contain spaces),
 i.e. let arg1 be your local equivalent of
 \"/usr/local/sas612/sas\"."
-    (shell)
-    (add-hook 'comint-output-filter-functions 'ess-exit-notify-sh) ;; 19.28
+;    (ess-sas-goto-shell)
+;    (add-hook 'comint-output-filter-functions 'ess-exit-notify-sh) ;; 19.28
                                           ;; nil t) works for newer emacsen
-    (insert "cd " (car (last (split-string (file-name-directory ess-sas-file-path) "\\(:\\|]\\)"))))
-    (comint-send-input)
-    (insert ess-sas-submit-pre-command " " arg1 " "  
+    (if (string-equal (substring (file-name-nondirectory ess-sas-file-path) 0 1) ess-kermit-prefix)
+      (progn
+       (if (ess-save-and-set-local-variables) (ess-kermit-send))
+       (let ((ess-temp-directory ess-kermit-remote-directory))
+        (ess-sas-goto-shell t)
+        (insert "cd " ess-temp-directory)
+        (comint-send-input)
+        (insert ess-sas-submit-pre-command " " arg1 " "  
+	 (substring (file-name-sans-extension (file-name-nondirectory ess-sas-file-path)) 1)
+	 " " arg2 " " ess-sas-submit-post-command))
+        ;(ess-sas-goto-sas)
+       )
+    ;;else
+      (ess-save-and-set-local-variables)
+      (ess-sas-goto-shell t)
+      (insert "cd " (car (last (split-string (file-name-directory ess-sas-file-path) "\\(:\\|]\\)"))))
+      (comint-send-input)
+      (insert ess-sas-submit-pre-command " " arg1 " "  
 	(file-name-sans-extension (file-name-nondirectory ess-sas-file-path)) 
 	" " arg2 " " ess-sas-submit-post-command)
-    (comint-send-input)
+      )
+    ;(comint-send-input)
     (ess-sleep)
     (comint-send-input))
 
@@ -584,7 +642,8 @@ spaces by enclosing the string in \\\"'s), i.e. let
 `ess-sas-submit-command' be \"\\\"C:\\Program Files\\SAS\\sas.exe\\\"\".
 Keep in mind that the maximum command line length in MS-DOS is
 127 characters so altering your PATH is preferable."
-    (shell)
+    (ess-save-and-set-local-variables)
+    (ess-sas-goto-shell t)
     (if (string-equal ":" (substring ess-sas-file-path 1 2)) 
 	(progn
 		(insert (substring ess-sas-file-path 0 2))
@@ -599,7 +658,6 @@ Keep in mind that the maximum command line length in MS-DOS is
 	arg2 " " ess-sas-submit-post-command)
     (comint-send-input))
 
-
 (defun ess-sas-tab-to-tab-stop ()
   "Tab to next tab-stop and set left margin."
   (interactive)
@@ -611,24 +669,17 @@ Keep in mind that the maximum command line length in MS-DOS is
   "Toggle SAS-log-mode for .log files."
   (interactive)
 
-  (if force (progn
-	      (setq auto-mode-alist (append '(("\\.log\\'" . SAS-log-mode)) auto-mode-alist))
-	      (setq auto-mode-alist (append '(("\\.LOG\\'" . SAS-log-mode)) auto-mode-alist)))
-    
-    (if (or (equal (prin1-to-string (cdr (assoc "\\.log\\'" auto-mode-alist))) "SAS-log-mode")
-	    (equal (prin1-to-string (cdr (assoc "\\.LOG\\'" auto-mode-alist))) "SAS-log-mode"))
-	(progn (setq auto-mode-alist (delete '("\\.log\\'" . SAS-log-mode) auto-mode-alist))
-	       (setq auto-mode-alist (delete '("\\.LOG\\'" . SAS-log-mode) auto-mode-alist)))
-      (setq auto-mode-alist (append '(("\\.log\\'" . SAS-log-mode)) auto-mode-alist))
-      (setq auto-mode-alist (append '(("\\.LOG\\'" . SAS-log-mode)) auto-mode-alist))))
+  (if (and (equal (cdr (assoc "\\.[lL][oO][gG]\\'" auto-mode-alist)) 'SAS-log-mode)
+	   (not force))
+      (setq auto-mode-alist (delete '("\\.[lL][oO][gG]\\'" . SAS-log-mode) auto-mode-alist))
+    (setq auto-mode-alist (append '(("\\.[lL][oO][gG]\\'" . SAS-log-mode)) auto-mode-alist)))
   
-  (if (or (equal (file-name-extension (buffer-file-name)) "log")
-	  (equal (file-name-extension (buffer-file-name)) "LOG"))
-    (progn (font-lock-mode 0)
-	   (normal-mode)
-	   (if (not (equal (prin1-to-string major-mode) "ess-mode"))
-	       (ess-transcript-minor-mode 0))
-	   (font-lock-mode 1))))
+  (if (equal (downcase (file-name-extension (buffer-file-name))) "log")
+      (progn (font-lock-mode 0)
+	     (normal-mode)
+	     (if (not (equal (prin1-to-string major-mode) "ess-mode"))
+		 (ess-transcript-minor-mode 0))
+	     (font-lock-mode 1))))
 
 (defun ess-sleep ()
 "Put emacs to sleep for `ess-sleep-for' seconds.
@@ -674,7 +725,7 @@ Without args, toggle between these options."
   "PC-like SAS key definitions"
   (interactive)
   (global-set-key (quote [f2]) 'ess-revert-wisely)
-  (global-set-key (quote [f3]) 'shell)
+  (global-set-key (quote [f3]) 'ess-sas-goto-shell)
   (global-set-key (quote [f4]) 'ess-sas-goto-file-1)
   (global-set-key (quote [f5]) 'ess-sas-goto-sas)
   (global-set-key (quote [f6]) 'ess-sas-goto-log)
@@ -685,11 +736,13 @@ Without args, toggle between these options."
   (global-set-key [(control f8)] 'ess-sas-submit-region)
   (global-set-key (quote [f9]) 'ess-sas-data-view)
   (global-set-key (quote [f10]) 'ess-sas-toggle-sas-log-mode)
-	(if (and ess-sas-edit-keys-toggle
-	    (equal emacs-major-version 19) (equal emacs-minor-version 28))
-	    (global-set-key [C-tab] 'ess-sas-backward-delete-tab)
-	    ;else
-	    (global-set-key [(control tab)] 'ess-sas-backward-delete-tab))
+  (global-set-key (quote [f11]) 'ess-sas-goto-file-2)
+  (global-set-key (quote [f12]) 'ess-sas-graph-view)
+  (if (and ess-sas-edit-keys-toggle
+	   (equal emacs-major-version 19) (equal emacs-minor-version 28))
+      (global-set-key [C-tab] 'ess-sas-backward-delete-tab)
+					;else
+    (global-set-key [(control tab)] 'ess-sas-backward-delete-tab))
   (define-key sas-mode-local-map "\C-c\C-p" 'ess-sas-file-path))
 
 (defvar ess-sas-global-unix-keys nil
@@ -706,10 +759,11 @@ Without args, toggle between these options."
   (global-set-key (quote [f6]) 'ess-sas-goto-lst)
   (global-set-key [(control f6)] 'ess-sas-append-lst)
   (global-set-key (quote [f7]) 'ess-sas-goto-file-1)
-  (global-set-key (quote [f8]) 'shell)
+  (global-set-key (quote [f8]) 'ess-sas-goto-shell)
   (global-set-key (quote [f9]) 'ess-sas-data-view)
   (global-set-key (quote [f10]) 'ess-sas-toggle-sas-log-mode)
   (global-set-key (quote [f11]) 'ess-sas-goto-file-2)
+  (global-set-key (quote [f12]) 'ess-sas-graph-view)
 	(if (and ess-sas-edit-keys-toggle
 	    (equal emacs-major-version 19) (equal emacs-minor-version 28))
 	    (global-set-key [C-tab] 'ess-sas-backward-delete-tab)
@@ -724,7 +778,7 @@ in SAS-mode and related modes.")
   "PC-like SAS key definitions."
   (interactive)
   (define-key sas-mode-local-map (quote [f2]) 'ess-revert-wisely)
-  (define-key sas-mode-local-map (quote [f3]) 'shell)
+  (define-key sas-mode-local-map (quote [f3]) 'ess-sas-goto-shell)
   (define-key sas-mode-local-map (quote [f4]) 'ess-sas-goto-file-1)
   (define-key sas-mode-local-map (quote [f5]) 'ess-sas-goto-sas)
   (define-key sas-mode-local-map (quote [f6]) 'ess-sas-goto-log)
@@ -736,6 +790,7 @@ in SAS-mode and related modes.")
   (define-key sas-mode-local-map (quote [f9]) 'ess-sas-data-view)
   (define-key sas-mode-local-map (quote [f10]) 'ess-sas-toggle-sas-log-mode)
   (define-key sas-mode-local-map (quote [f11]) 'ess-sas-goto-file-2)
+  (define-key sas-mode-local-map (quote [f12]) 'ess-sas-graph-view)
   (define-key sas-mode-local-map "\C-c\C-p" 'ess-sas-file-path))
 
 (defvar ess-sas-local-unix-keys nil
@@ -753,10 +808,11 @@ in SAS-mode and related modes.")
   (define-key sas-mode-local-map (quote [f6]) 'ess-sas-goto-lst)
   (define-key sas-mode-local-map [(control f6)] 'ess-sas-append-lst)
   (define-key sas-mode-local-map (quote [f7]) 'ess-sas-goto-file-1)
-  (define-key sas-mode-local-map (quote [f8]) 'shell)
+  (define-key sas-mode-local-map (quote [f8]) 'ess-sas-goto-shell)
   (define-key sas-mode-local-map (quote [f9]) 'ess-sas-data-view)
   (define-key sas-mode-local-map (quote [f10]) 'ess-sas-toggle-sas-log-mode)
   (define-key sas-mode-local-map (quote [f11]) 'ess-sas-goto-file-2)
+  (define-key sas-mode-local-map (quote [f12]) 'ess-sas-graph-view)
   (define-key sas-mode-local-map "\C-c\C-p" 'ess-sas-file-path))
 
 
