@@ -8,9 +8,9 @@
 ;; Maintainers: A.J. Rossini <rossini@u.washington.edu>
 ;;              M. Maechler <maechler@stat.math.ethz.ch>
 ;; Created: 12 Jun 1997
-;; Modified: $Date: 2002/01/20 06:14:36 $
-;; Version: $Revision: 5.34 $
-;; RCS: $Id: essd-r.el,v 5.34 2002/01/20 06:14:36 rmh Exp $
+;; Modified: $Date: 2002/06/24 07:48:01 $
+;; Version: $Revision: 5.40 $
+;; RCS: $Id: essd-r.el,v 5.40 2002/06/24 07:48:01 maechler Exp $
 ;;
 ;; Keywords: start up, configuration.
 
@@ -69,8 +69,9 @@
     (inferior-ess-objects-command  . "objects(pos = %d)\n")
     (inferior-ess-search-list-command   . "search()\n")
     (inferior-ess-help-command     . "help(\"%s\", htmlhelp=FALSE)\n")
-    (inferior-ess-exit-command     . "q()\n")
-    (inferior-ess-primary-prompt   . "[A-Za-z0-9.]*> ")
+    (inferior-ess-exit-command     . "q()")
+    (inferior-ess-exit-prompt      . "Save workspace image? [y/n/c]: ")
+    (inferior-ess-primary-prompt   . "\\([A-Z][][A-Za-z0-9.]*\\)*> ")
     (inferior-ess-secondary-prompt . "+ ?")
     (comint-use-prompt-regexp-instead-of-fields . t) ;; emacs 21 and up
     (inferior-ess-start-file       . nil)            ;; "~/.ess-R"
@@ -78,15 +79,8 @@
     (ess-STERM  . "iESS")
     (ess-editor . R-editor)
     (ess-pager  . R-pager)
-    (inferior-ess-language-start .
-				 (concat "options("
-					 "STERM='"  ess-STERM  "'"
-					 (if ess-editor 
-					     (concat ", editor='" ess-editor "'"))
-					 (if ess-pager 
-					     (concat ", pager='"  ess-pager  "'"))
-					 ")"))
-)
+    (inferior-ess-language-start . (eval inferior-S-language-start))
+    )
   "Variables to customize for R")
 
 ;;; AJR: Need to condition on this...!
@@ -119,6 +113,9 @@ Optional prefix (C-u) allows to set command line arguments, such as --vsize."
     (if ess-microsoft-p
 	(setq default-process-coding-system '(undecided-dos . undecided-dos)))
     (inferior-ess r-start-args) ;; (R)
+    (ess-write-to-dribble-buffer
+     (format "(R): inferior-ess-language-start=%s\n"
+	     inferior-ess-language-start))
     (if inferior-ess-language-start
 	(ess-eval-linewise inferior-ess-language-start))))
 
@@ -129,9 +126,13 @@ Optional prefix (C-u) allows to set command line arguments, such as --vsize."
   (setq ess-customize-alist R-customize-alist)
   ;;(setq imenu-generic-expression R-imenu-generic-expression)
   (ess-mode R-customize-alist proc-name)
-  ;;; AJR: Need to condition on this...!
-  ;; MM: and you probably should really use ess-imenu-mode-function from above!
-  (ess-imenu-R))
+  ;; ECB needs seminatic stuff.
+  ;;  (if (featurep 'semantic)
+  ;;      (setq semantic-toplevel-bovine-table r-toplevel-bovine-table))
+  ;; AJR: Need to condition on this...!
+  ;; MM: and you probably should really use ess-imenu-mode-function from the
+  ;;     alist above!
+  (if ess-S-use-imenu (ess-imenu-R)))
 
 (fset 'r-mode 'R-mode)
 
