@@ -5,9 +5,9 @@
 ;; Author: A.J. Rossini <rossini@stat.sc.edu>
 ;; Maintainer: A.J. Rossini <rossini@stat.sc.edu>
 ;; Created: 12 Jun 1997
-;; Modified: $Date: 2002/01/20 06:14:36 $
-;; Version: $Revision: 5.8 $
-;; RCS: $Id: essd-s4.el,v 5.8 2002/01/20 06:14:36 rmh Exp $
+;; Modified: $Date: 2002/06/24 07:48:01 $
+;; Version: $Revision: 5.10 $
+;; RCS: $Id: essd-s4.el,v 5.10 2002/06/24 07:48:01 maechler Exp $
 ;;
 ;; Keywords: start up, configuration.
 
@@ -84,15 +84,8 @@
     (ess-STERM  . "iESS")
     (ess-editor . S-editor)
     (ess-pager  . S-pager)
-    (inferior-ess-language-start .
-				 (concat "options("
-					 "STERM='"  ess-STERM  "'"
-					 (if ess-editor 
-					     (concat ", editor='" ess-editor "'"))
-					 (if ess-pager 
-					     (concat ", pager='"  ess-pager  "'"))
-					 ")"))
-)
+    (inferior-ess-language-start . (eval inferior-S-language-start))
+    )
   "Variables to customize for S4.")
 
 ;; For loading up the S code required for the above.
@@ -123,7 +116,8 @@
   "Major mode for editing S4 source.  See `ess-mode' for more help."
   (interactive)
   (setq ess-customize-alist S4-customize-alist)
-  (ess-mode S4-customize-alist proc-name))
+  (ess-mode S4-customize-alist proc-name)
+  (if ess-S-use-imenu (ess-imenu-R)))
 
 
 ;; From RMH:    ALL THIS SHOULD BE INCORPORATED BY 5.0!
