@@ -5,9 +5,9 @@
 ;; Author: A.J. Rossini <rossini@stat.sc.edu>
 ;; Maintainer: A.J. Rossini <rossini@stat.sc.edu>
 ;; Created: 12 Jun 1997
-;; Modified: $Date: 2002/01/20 06:14:36 $
-;; Version: $Revision: 1.7 $
-;; RCS: $Id: essd-sp3.el,v 1.7 2002/01/20 06:14:36 rmh Exp $
+;; Modified: $Date: 2002/06/24 07:48:01 $
+;; Version: $Revision: 1.9 $
+;; RCS: $Id: essd-sp3.el,v 1.9 2002/06/24 07:48:01 maechler Exp $
 ;;
 ;; Keywords: start up, configuration.
 
@@ -73,15 +73,8 @@
     (ess-STERM  . "iESS")
     (ess-editor . S-editor)
     (ess-pager  . S-pager)
-    (inferior-ess-language-start .
-				 (concat "options("
-					 "STERM='"  ess-STERM  "'"
-					 (if ess-editor 
-					     (concat ", editor='" ess-editor "'"))
-					 (if ess-pager 
-					     (concat ", pager='"  ess-pager  "'"))
-					 ")"))
-)
+    (inferior-ess-language-start . (eval inferior-S-language-start))
+    )
  "Variables to customize for S+3.")
 
 
@@ -99,7 +92,8 @@
   "Major mode for editing S+3 source.  See `ess-mode' for more help."
   (interactive)
   (setq ess-customize-alist S+3-customize-alist)
-  (ess-mode S+3-customize-alist proc-name))
+  (ess-mode S+3-customize-alist proc-name)
+  (if ess-S-use-imenu (ess-imenu-R)))
 
 (defun S+3-transcript-mode ()
   "S-PLUS 3.x transcript mode."
