@@ -6,9 +6,9 @@
 ;; Author: Richard M. Heiberger <rmh@fisher.stat.temple.edu>
 ;; Maintainer: A.J. Rossini <rossini@biostat.washington.edu>
 ;; Created: December 1998
-;; Modified: $Date: 2002/01/21 03:26:13 $
-;; Version: $Revision: 1.10 $
-;; RCS: $Id: essd-sp4.el,v 1.10 2002/01/21 03:26:13 rmh Exp $
+;; Modified: $Date: 2002/06/24 07:48:01 $
+;; Version: $Revision: 1.14 $
+;; RCS: $Id: essd-sp4.el,v 1.14 2002/06/24 07:48:01 maechler Exp $
 ;;
 ;; Keywords: start up, configuration.
 
@@ -90,15 +90,8 @@ connects it to the '(ddeESS [S+4])' window.")
     (ess-STERM  . "ddeESS")
     (ess-editor . S-editor)
     (ess-pager  . S-pager)
-    (inferior-ess-language-start .
-				 (concat "options("
-					 "STERM='"  ess-STERM  "'"
-					 (if ess-editor 
-					     (concat ", editor='" ess-editor "'"))
-					 (if ess-pager 
-					     (concat ", pager='"  ess-pager  "'"))
-					 ")"))
-)
+    (inferior-ess-language-start . (eval inferior-S-language-start))
+    )
  "Variables to customize for S+4")
 
 (defvar Sqpe+4-customize-alist
@@ -134,9 +127,9 @@ connects it to the '(ddeESS [S+4])' window.")
     (inferior-ess-language-start .
 				 (concat "options("
 					 "STERM='"  ess-STERM  "'"
-					 (if ess-editor 
+					 (if ess-editor
 					     (concat ", editor='" ess-editor "'"))
-					 (if ess-pager 
+					 (if ess-pager
 					     (concat ", pager='"  ess-pager  "'"))
 					 ")"))
 )
@@ -328,8 +321,7 @@ Splus Commands window blink a DOS window and you won't see them.\n\n")
   (interactive)
   (setq ess-customize-alist S+4-customize-alist)
   (ess-mode S+4-customize-alist proc-name)
-)
-
+  (if ess-S-use-imenu (ess-imenu-R)))
 
 (defun S+4-transcript-mode ()
   "S-PLUS 4.x transcript mode."
