@@ -9,9 +9,9 @@
 ;; Maintainer: Richard M. Heiberger <rmh@astro.ocis.temple.edu>,
 ;;             Rodney Sparapani <rsparap@mcw.edu>
 ;; Created: 20 Aug 1997
-;; Modified: $Date: 2002/01/31 21:57:51 $
-;; Version: $Revision: 5.39 $
-;; RCS: $Id: essl-sas.el,v 5.39 2002/01/31 21:57:51 rsparapa Exp $
+;; Modified: $Date: 2002/04/12 21:46:24 $
+;; Version: $Revision: 5.42 $
+;; RCS: $Id: essl-sas.el,v 5.42 2002/04/12 21:46:24 rsparapa Exp $
 ;;
 ;; Keywords: start up, configuration.
 
@@ -383,7 +383,7 @@ number."
 	 ;; SAS comments
 ;; /* */ handled by grammar above
 ;;	 (list "/\\*.*\\*/"                      0  font-lock-comment-face t)
-	 (cons "\\(^[0-9]*\\|;\\)[ \t]*%?\\*.*\\(;\\|$\\)" font-lock-comment-face)
+	 (cons "\\(^[0-9]*\\|;\\)[ \t]*\\(%?\\*\\|comment\\).*\\(;\\|$\\)" font-lock-comment-face)
 
 	 ;; SAS execution blocks, DATA/RUN, PROC/RUN, SAS Macro Statements
 	 (cons "\\<%do[ \t]*\\(%until\\|%while\\)?\\>"
@@ -419,15 +419,17 @@ number."
 		"\\|var\\|where\\)"
 		"[ \t]*=")
 						    font-lock-keyword-face)
-	 (cons "\\<\\(in\\(dex[ \t]*=\\)?\\|until\\|wh\\(en\\|ile\\)\\)[ \t]*("
+	 (cons "\\<\\(in\\(:\\|dex[ \t]*=\\)?\\|until\\|wh\\(en\\|ile\\)\\)[ \t]*("
 						    font-lock-keyword-face)
 
 	 ;; SAS statements
 
 	 (cons (concat
 		"\\(^[0-9]*\\|):\\|[;,]\\|then\\|else\\)[ \t]*"
-		"\\(a\\(bort\\|rray\\|ttrib\\)\\|by\\|c\\(hange\\|lass\\)"
-		"\\|d\\(elete\\|isplay\\|m\\|rop\\)\\|e\\(rror\\|xc\\(hange\\|lude\\)\\)"
+		"\\(a\\(bort\\|rray\\|ttrib\\)\\|by"
+		"\\|c\\(hange\\|lass\\|ontrast\\)"
+		"\\|d\\(elete\\|isplay\\|m\\|rop\\)"
+		"\\|e\\(rror\\|stimate\\|xc\\(hange\\|lude\\)\\)"
 		"\\|f\\(ile\\(name\\)?\\|o\\(otnote\\(10?\\|[2-9]\\)?\\|rmat\\)\\|req\\)"
 		"\\|go\\([ \t]*to\\|ptions\\)"
 		"\\|i\\(d\\|f\\|n\\(dex\\|f\\(ile\\|ormat\\)\\|put\\|value\\)\\)"
